.. _tutorials-and-presentations:

Tutorials and Presentations
===========================

Tutorials
---------

.. toctree::
    :maxdepth: 1
    :hidden:

    demo

.. grid:: 1 2 2 2
    :gutter: 2


    .. grid-item-card::
       :text-align: center
       :link: demo.html

       .. image:: _static/demo.jpg
           :alt: Eddy-footprint demonstration
       +++
       Eddy-footprint demonstration

Presentations
-------------

.. grid:: 1 2 2 2
    :gutter: 2


    .. grid-item-card::
       :text-align: center
       :link: https://agu.confex.com/agu/fm23/meetingapp.cgi/Paper/1418503

       Eddy-footprint: an open-source Python package for generating eddy covariance footprints

       +++
       2023 AGU Fall Meeting
